/**
 * <p>Describes an individual setting that controls some aspect of ElastiCache behavior.</p>
 */
export interface _Parameter {
    /**
     * <p>The name of the parameter.</p>
     */
    ParameterName?: string;
    /**
     * <p>The value of the parameter.</p>
     */
    ParameterValue?: string;
    /**
     * <p>A description of the parameter.</p>
     */
    Description?: string;
    /**
     * <p>The source of the parameter.</p>
     */
    Source?: string;
    /**
     * <p>The valid data type for the parameter.</p>
     */
    DataType?: string;
    /**
     * <p>The valid range of values for the parameter.</p>
     */
    AllowedValues?: string;
    /**
     * <p>Indicates whether (<code>true</code>) or not (<code>false</code>) the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.</p>
     */
    IsModifiable?: boolean;
    /**
     * <p>The earliest cache engine version to which the parameter can apply.</p>
     */
    MinimumEngineVersion?: string;
    /**
     * <p>Indicates whether a change to the parameter is applied immediately or requires a reboot for the change to be applied. You can force a reboot or wait until the next maintenance window's reboot. For more information, see <a href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/Clusters.Rebooting.html">Rebooting a Cluster</a>.</p>
     */
    ChangeType?: "immediate" | "requires-reboot" | string;
}
export declare type _UnmarshalledParameter = _Parameter;
